ParseError class

Error in parsed document.

Implemented types

Constructors

ParseError(String errorCode, SourceSpan? span, Map<String, Object?>? data)

Properties

column → int
no setter
data → Map<String, Object?>?
final
errorCode → String
final
hashCode → int
The hash code for this object.
no setterinherited
line → int
no setter
message → String
Returns the human readable error message for this error.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan?
The span associated with this exception.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({dynamic color}) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited